:mod:`easymode.utils`
=====================

.. automodule:: easymode.utils
    :members:

:mod:`easymode.utils.xmlutils`
==============================

.. automodule:: easymode.utils.xmlutils
    :members:
            
:mod:`easymode.utils.languagecode`
==================================

.. automodule:: easymode.utils.languagecode
    :members:

:mod:`easymode.utils.polibext`
==============================

.. automodule:: easymode.utils.polibext
    :members:
 
:mod:`easymode.utils.standin`
==============================

.. automodule:: easymode.utils.standin
    :members:

:mod:`easymode.utils.template`
==============================

.. automodule:: easymode.utils.template
    :members:
